@@ -25,13 +25,14 @@
 #include "gog-plot-impl.h"
 #include "gog-object-xml.h"
 #include "gog-data-allocator.h"
-#include "gog-style.h"
 #include "gog-renderer.h"
 #include <goffice/data/go-data-impl.h>
 #include <goffice/data/go-data.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-path.h>
 #include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-libxml-extras.h>
 #include <gsf/gsf-impl-utils.h>
 
 #include <glib/gi18n-lib.h>
@@ -160,7 +161,7 @@ cb_type_changed (GtkWidget *w, GogErrorBarEditor *editor)
 	} else {
 		GtkWidget *table = glade_xml_get_widget (gui, "values_table");
 		if (!editor->bar) {
-			editor->bar = g_object_new (GOG_ERROR_BAR_TYPE, NULL);
+			editor->bar = g_object_new (GOG_TYPE_ERROR_BAR, NULL);
 			editor->bar->style->line.color = editor->color;
 			editor->bar->style->line.width = editor->line_width;
 			editor->bar->width = editor->width;
@@ -213,7 +214,7 @@ gog_error_bar_prefs (GogSeries *series,
 	GogErrorBarEditor *editor;
 	unsigned int i;
 
-	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
+	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
 
 	editor = g_new0 (GogErrorBarEditor, 1);
 	editor->series = series;
@@ -232,7 +233,7 @@ gog_error_bar_prefs (GogSeries *series,
 	}
 	set = GOG_DATASET (series);
 
-	gui = go_libglade_new ("gog-error-bar-prefs.glade", "gog_error_bar_prefs", GETTEXT_PACKAGE, cc);
+	gui = go_glade_new ("gog-error-bar-prefs.glade", "gog_error_bar_prefs", GETTEXT_PACKAGE, cc);
 
 	/* Style properties */
 
@@ -329,8 +330,8 @@ gog_error_bar_init (GogErrorBar* bar)
 	bar->type = GOG_ERROR_BAR_TYPE_NONE;
 	bar->display = GOG_ERROR_BAR_DISPLAY_BOTH;
 	bar->width = 5.;
-	bar->style = gog_style_new ();
-	bar->style->interesting_fields = GOG_STYLE_LINE;
+	bar->style = go_style_new ();
+	bar->style->interesting_fields = GO_STYLE_LINE;
 	bar->style->line.color = RGBA_BLACK;
 	bar->style->line.width = 1.;
 }
@@ -476,7 +477,7 @@ gog_error_bar_persist_init (GOPersistClass *iface)
 GSF_CLASS_FULL (GogErrorBar, gog_error_bar,
 		NULL, NULL, gog_error_bar_class_init, NULL,
 		gog_error_bar_init, G_TYPE_OBJECT, 0,
-		GSF_INTERFACE (gog_error_bar_persist_init, GO_PERSIST_TYPE))
+		GSF_INTERFACE (gog_error_bar_persist_init, GO_TYPE_PERSIST))
 
 
 /**
@@ -499,39 +500,39 @@ gog_error_bar_get_bounds (GogErrorBar const *bar, int index, double *min, double
 {
 	double value;
 	GOData *data;
-	GODataVector *vec;
+	GOData *vec;
 	int length;
 
 	/* -1 ensures that the bar will not be displayed if the error is not a correct one.
 		With a 0 value, it might be, because of rounding errors */
 	*min = *max = -1.;
 
-	g_return_val_if_fail (IS_GOG_ERROR_BAR (bar), FALSE);
+	g_return_val_if_fail (GOG_IS_ERROR_BAR (bar), FALSE);
 	if (!gog_series_is_valid (bar->series))
 		return FALSE;
-	vec = GO_DATA_VECTOR (bar->series->values[bar->dim_i].data);
+	vec = bar->series->values[bar->dim_i].data;
 	if (vec == NULL || index < 0)
 		return FALSE;
-	value = go_data_vector_get_value (vec, index);
+	value = go_data_get_vector_value (vec, index);
 	data = bar->series->values[bar->error_i].data;
-	length = (IS_GO_DATA (data)) ? go_data_vector_get_len (GO_DATA_VECTOR (data)) : 0;
+	length = (GO_IS_DATA (data)) ? go_data_get_vector_size (data) : 0;
 
 	if ((bar->type == GOG_ERROR_BAR_TYPE_NONE) || isnan (value) || !go_finite (value))
 		return FALSE;
 
 	if (length == 1)
-		*max = go_data_vector_get_value (GO_DATA_VECTOR (data), 0);
+		*max = go_data_get_vector_value (data, 0);
 	else if (length > index)
-		*max = go_data_vector_get_value (GO_DATA_VECTOR (data), index);
+		*max = go_data_get_vector_value (data, index);
 
 	data = bar->series->values[bar->error_i + 1].data;
-	length = (IS_GO_DATA (data))? go_data_vector_get_len (GO_DATA_VECTOR (data)): 0;
+	length = (GO_IS_DATA (data))? go_data_get_vector_size (data): 0;
 	if (length == 0)
 		*min = *max; /* use same values for + and - */
 	else if (length == 1)
-		*min = go_data_vector_get_value (GO_DATA_VECTOR (data), 0);
+		*min = go_data_get_vector_value (data, 0);
 	else if (length > index)
-		*min = go_data_vector_get_value (GO_DATA_VECTOR (data), index);
+		*min = go_data_get_vector_value (data, index);
 
 	if (isnan (*min) || !go_finite (*min) || (*min <= 0)) {
 		*min = -1.;
@@ -563,7 +564,7 @@ gog_error_bar_get_minmax (const GogErrorBar *bar, double *min, double *max)
 	int i, imax;
 	double tmp_min, tmp_max, plus, minus;
 	
-	g_return_if_fail (IS_GOG_ERROR_BAR (bar));
+	g_return_if_fail (GOG_IS_ERROR_BAR (bar));
 
 	if (!gog_series_is_valid (bar->series)) {
 		*min = DBL_MAX;
@@ -571,11 +572,11 @@ gog_error_bar_get_minmax (const GogErrorBar *bar, double *min, double *max)
 		return;
 	}
 
-	imax = go_data_vector_get_len (GO_DATA_VECTOR (bar->series->values[bar->dim_i].data));
+	imax = go_data_get_vector_size (bar->series->values[bar->dim_i].data);
 	if (imax == 0)
 		return;
-	go_data_vector_get_minmax (GO_DATA_VECTOR (bar->series->values[bar->dim_i].data), min, max);
-	values = go_data_vector_get_values (GO_DATA_VECTOR (bar->series->values[bar->dim_i].data));
+	go_data_get_bounds (bar->series->values[bar->dim_i].data, min, max);
+	values = go_data_get_values (bar->series->values[bar->dim_i].data);
 
 	for (i = 0; i < imax; i++) {
 		if  (gog_error_bar_get_bounds (bar, i, &minus, &plus)) {
@@ -594,9 +595,9 @@ gog_error_bar_dup		(GogErrorBar const *bar)
 {
 	GogErrorBar* dbar;
 
-	g_return_val_if_fail (IS_GOG_ERROR_BAR (bar), NULL);
+	g_return_val_if_fail (GOG_IS_ERROR_BAR (bar), NULL);
 
-	dbar = g_object_new (GOG_ERROR_BAR_TYPE, NULL);
+	dbar = g_object_new (GOG_TYPE_ERROR_BAR, NULL);
 	dbar->type = bar->type;
 	dbar->series = bar->series;
 	dbar->dim_i = bar->dim_i;
@@ -604,7 +605,7 @@ gog_error_bar_dup		(GogErrorBar const *bar)
 	dbar->display = bar->display;
 	dbar->width = bar->width;
 	if (dbar->style) g_object_unref (dbar->style);
-	dbar->style = gog_style_dup (bar->style);
+	dbar->style = go_style_dup (bar->style);
 	return dbar;
 }
 
