@@ -27,48 +27,17 @@
 #include <goffice/graph/gog-data-set.h>
 #include <goffice/data/go-data.h>
 #include <goffice/utils/go-color.h>
+#include <goffice/utils/go-persist.h>
 
 #include <string.h>
 #include <stdlib.h>
 
-GType
-gog_persist_get_type (void)
-{
-	static GType gog_persist_type = 0;
+/* GogGrid object was used with "Grid" role name by GogChart. We've changed the role
+ * name to "Backplane", since that's what the user see in the UI, and that's what GogGrid
+ * really is. We do the substitution on save/load for backward compatibility. */
 
-	if (!gog_persist_type) {
-		static GTypeInfo const gog_persist_info = {
-			sizeof (GogPersistClass),	/* class_size */
-			NULL,		/* base_init */
-			NULL,		/* base_finalize */
-		};
-
-		gog_persist_type = g_type_register_static (G_TYPE_INTERFACE,
-			"GogPersist", &gog_persist_info, 0);
-	}
-
-	return gog_persist_type;
-}
-
-gboolean
-gog_persist_dom_load (GogPersist *gp, xmlNode *node)
-{
-	g_return_val_if_fail (IS_GOG_PERSIST (gp), FALSE);
-	return GOG_PERSIST_GET_CLASS (gp)->dom_load (gp, node);
-}
-
-void
-gog_persist_sax_save (GogPersist const *gp, GsfXMLOut *output)
-{
-	g_return_if_fail (IS_GOG_PERSIST (gp));
-	GOG_PERSIST_GET_CLASS (gp)->sax_save (gp, output);
-}
-void
-gog_persist_prep_sax (GogPersist *gp, GsfXMLIn *xin, xmlChar const **attrs)
-{
-	g_return_if_fail (IS_GOG_PERSIST (gp));
-	GOG_PERSIST_GET_CLASS (gp)->prep_sax (gp, xin, attrs);
-}
+#define GOG_BACKPLANE_OLD_ROLE_NAME	"Grid"
+#define GOG_BACKPLANE_NEW_ROLE_NAME	"Backplane"
 
 static void
 gog_object_set_arg_full (char const *name, char const *val, GogObject *obj, xmlNode *xml_node)
@@ -108,8 +77,8 @@ gog_object_set_arg_full (char const *name, char const *val, GogObject *obj, xmlN
 			xmlFree (type_name);
 			if (type != 0) {
 				val_obj = g_object_new (type, NULL);
-				if (IS_GOG_PERSIST (val_obj) &&
-				    gog_persist_dom_load (GOG_PERSIST (val_obj), xml_node)) {
+				if (GO_IS_PERSIST (val_obj) &&
+				    go_persist_dom_load (GO_PERSIST (val_obj), xml_node)) {
 					g_value_set_object (&res, val_obj);
 					success = TRUE;
 				}
@@ -190,10 +159,10 @@ gog_object_write_property_sax (GogObject const *obj, GParamSpec *pspec, GsfXMLOu
 	case G_TYPE_OBJECT:
 		val_obj = g_value_get_object (&value);
 		if (val_obj != NULL) {
-			if (IS_GOG_PERSIST (val_obj)) {
+			if (GO_IS_PERSIST (val_obj)) {
 				gsf_xml_out_start_element (output, "property");
 				gsf_xml_out_add_cstr_unchecked (output, "name", pspec->name);
-				gog_persist_sax_save (GOG_PERSIST (val_obj), output);
+				go_persist_sax_save (GO_PERSIST (val_obj), output);
 				gsf_xml_out_end_element (output); /* </property> */
 			} else
 				g_warning ("How are we supposed to persist this ??");
@@ -208,7 +177,7 @@ gog_object_write_property_sax (GogObject const *obj, GParamSpec *pspec, GsfXMLOu
 }
 
 static void
-gog_dataset_dom_load (GogDataset *set, xmlNode *node)
+gog_dataset_dom_load (GogDataset *set, xmlNode *node, gpointer user)
 {
 	xmlNode *ptr;
 	xmlChar *id, *val, *type;
@@ -231,7 +200,7 @@ gog_dataset_dom_load (GogDataset *set, xmlNode *node)
 			if (id != NULL && type != NULL && val != NULL) {
 				unsigned dim_id = strtoul (id, NULL, 0);
 				GOData *dat = g_object_new (g_type_from_name (type), NULL);
-				if (dat != NULL && go_data_from_str (dat, val))
+				if (dat != NULL && go_data_unserialize (dat, val, user))
 					gog_dataset_set_dim (set, dim_id, dat, NULL);
 			}
 
@@ -243,7 +212,7 @@ gog_dataset_dom_load (GogDataset *set, xmlNode *node)
 }
 
 static void
-gog_dataset_sax_save (GogDataset const *set, GsfXMLOut *output)
+gog_dataset_sax_save (GogDataset const *set, GsfXMLOut *output, gpointer user)
 {
 	GOData  *dat;
 	char    *tmp;
@@ -260,7 +229,7 @@ gog_dataset_sax_save (GogDataset const *set, GsfXMLOut *output)
 		gsf_xml_out_add_int (output, "id", i);
 		gsf_xml_out_add_cstr (output, "type", 
 			G_OBJECT_TYPE_NAME (dat));
-		tmp = go_data_as_str (dat);
+		tmp = go_data_serialize (dat, user);
 		gsf_xml_out_add_cstr (output, NULL, tmp);
 		g_free (tmp);
 		gsf_xml_out_end_element (output); /* </dimension> */
@@ -270,44 +239,48 @@ gog_dataset_sax_save (GogDataset const *set, GsfXMLOut *output)
 }
 
 void
-gog_object_write_xml_sax (GogObject const *obj, GsfXMLOut *output)
+gog_object_write_xml_sax (GogObject const *obj, GsfXMLOut *output, gpointer user)
 {
 	guint	     n;
 	GParamSpec **props;
 	GSList	    *ptr;
 
-	g_return_if_fail (IS_GOG_OBJECT (obj));
+	g_return_if_fail (GOG_IS_OBJECT (obj));
 
 	gsf_xml_out_start_element (output, "GogObject");
 
 	/* Primary details */
-	if (obj->role != NULL)
-		gsf_xml_out_add_cstr (output, "role", obj->role->id);
+	if (obj->role != NULL) {
+		if (strcmp (obj->role->id, GOG_BACKPLANE_NEW_ROLE_NAME) == 0)
+			gsf_xml_out_add_cstr (output, "role", GOG_BACKPLANE_OLD_ROLE_NAME);
+		else
+			gsf_xml_out_add_cstr (output, "role", obj->role->id);
+	}
 	if (obj->explicitly_typed_role || obj->role == NULL)
 		gsf_xml_out_add_cstr (output, "type", G_OBJECT_TYPE_NAME (obj));
 
 	/* properties */
 	props = g_object_class_list_properties (G_OBJECT_GET_CLASS (obj), &n);
 	while (n-- > 0)
-		if (props[n]->flags & GOG_PARAM_PERSISTENT)
+		if (props[n]->flags & GO_PARAM_PERSISTENT)
 			gog_object_write_property_sax (obj, props[n], output);
 
 	g_free (props);
 
-	if (IS_GOG_PERSIST (obj))	/* anything special for this class */
-		gog_persist_sax_save (GOG_PERSIST (obj), output);
-	if (IS_GOG_DATASET (obj))	/* convenience to save data */
-		gog_dataset_sax_save (GOG_DATASET (obj), output);
+	if (GO_IS_PERSIST (obj))	/* anything special for this class */
+		go_persist_sax_save (GO_PERSIST (obj), output);
+	if (GOG_IS_DATASET (obj))	/* convenience to save data */
+		gog_dataset_sax_save (GOG_DATASET (obj), output, user);
 
 	/* the children */
 	for (ptr = obj->children; ptr != NULL ; ptr = ptr->next)
-		gog_object_write_xml_sax (ptr->data, output);
+		gog_object_write_xml_sax (ptr->data, output, user);
 
 	gsf_xml_out_end_element (output); /* </GogObject> */
 }
 
 GogObject *
-gog_object_new_from_xml (GogObject *parent, xmlNode *node)
+gog_object_new_from_xml (GogObject *parent, xmlNode *node, gpointer user)
 {
 	xmlChar   *role, *name, *val, *type_name;
 	xmlNode   *ptr;
@@ -333,7 +306,11 @@ gog_object_new_from_xml (GogObject *parent, xmlNode *node)
 	if (role == NULL) {
 		g_return_val_if_fail (parent == NULL, NULL);
 	} else {
-		res = gog_object_add_by_name (parent, role, res);
+		/* FIXME */
+		if (strcmp (role, GOG_BACKPLANE_OLD_ROLE_NAME) == 0)
+			res = gog_object_add_by_name (parent, GOG_BACKPLANE_NEW_ROLE_NAME, res);
+		else
+			res = gog_object_add_by_name (parent, role, res);
 		xmlFree (role);
 	}
 
@@ -341,10 +318,10 @@ gog_object_new_from_xml (GogObject *parent, xmlNode *node)
 
 	res->explicitly_typed_role = explicitly_typed_role;
 
-	if (IS_GOG_PERSIST (res))
-		gog_persist_dom_load (GOG_PERSIST (res), node);
-	if (IS_GOG_DATASET (res))	/* convenience to save data */
-		gog_dataset_dom_load (GOG_DATASET (res), node);
+	if (GO_IS_PERSIST (res))
+		go_persist_dom_load (GO_PERSIST (res), node);
+	if (GOG_IS_DATASET (res))	/* convenience to save data */
+		gog_dataset_dom_load (GOG_DATASET (res), node, user);
 
 	for (ptr = node->xmlChildrenNode ; ptr != NULL ; ptr = ptr->next) {
 		if (xmlIsBlankNode (ptr) || ptr->name == NULL)
@@ -360,7 +337,7 @@ gog_object_new_from_xml (GogObject *parent, xmlNode *node)
 			xmlFree (val);
 			xmlFree (name);
 		} else if (!strcmp (ptr->name, "GogObject"))
-			gog_object_new_from_xml (res, ptr);
+			gog_object_new_from_xml (res, ptr, user);
 	}
 	return res;
 }
@@ -373,8 +350,9 @@ typedef struct {
 	GOData		*dimension;
 	unsigned	 dimension_id;
 
-	GogObjectSaxHandler	handler;
-	gpointer		user_data;
+	GogObjectSaxHandler handler;
+	gpointer user_data;
+	gpointer user_unserialize;
 } GogXMLReadState;
 
 GogObject *
@@ -393,7 +371,7 @@ gogo_dim_start (GsfXMLIn *xin, xmlChar const **attrs)
 	if (NULL == state->obj)
 		return;
 
-	g_return_if_fail (IS_GOG_DATASET (state->obj));
+	g_return_if_fail (GOG_IS_DATASET (state->obj));
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
 		if (0 == strcmp (attrs[0], "id"))
@@ -433,10 +411,12 @@ gogo_dim_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *unknown)
 	if (NULL == state->obj)
 		return;
 
-	g_return_if_fail (IS_GOG_DATASET (state->obj));
+	g_return_if_fail (GOG_IS_DATASET (state->obj));
 
 	if (NULL != state->dimension) {
-		if (go_data_from_str (state->dimension, xin->content->str))
+		if (go_data_unserialize (state->dimension,
+					 xin->content->str,
+					 state->user_unserialize))
 			gog_dataset_set_dim (GOG_DATASET (state->obj),
 				state->dimension_id, state->dimension, NULL);
 		else
@@ -483,14 +463,14 @@ gogo_prop_start (GsfXMLIn *xin, xmlChar const **attrs)
 		GogObject *obj;
 
 		if (NULL == type_str) {
-			g_warning ("missing type for property property `%s' of class `%s'",
+			g_warning ("missing type for property `%s' of class `%s'",
 				   prop_str, G_OBJECT_TYPE_NAME (state->obj));
 			return;
 		}
 
 		type = g_type_from_name (type_str);
 		if (0 == type) {
-			g_warning ("unknown type '%s' for property property `%s' of class `%s'",
+			g_warning ("unknown type '%s' for property `%s' of class `%s'",
 				   type_str, prop_str, G_OBJECT_TYPE_NAME (state->obj));
 			return;
 		}
@@ -501,8 +481,8 @@ gogo_prop_start (GsfXMLIn *xin, xmlChar const **attrs)
 		state->obj_stack = g_slist_prepend (state->obj_stack, state->obj);
 		state->obj = obj;
 		state->prop_pushed_obj = TRUE;
-		if (IS_GOG_PERSIST (obj))
-			gog_persist_prep_sax (GOG_PERSIST (obj), xin, attrs);
+		if (GO_IS_PERSIST (obj))
+			go_persist_prep_sax (GO_PERSIST (obj), xin, attrs);
 	}
 }
 
@@ -539,7 +519,7 @@ gogo_prop_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *unknown)
 			return;
 		}
 
-		if (!gsf_xml_gvalue_from_str (&val, prop_ftype, content)) {
+		if (!gsf_xml_gvalue_from_str (&val, prop_type, content)) {
 			g_warning ("could not convert string to type `%s' for property `%s'",
 				   g_type_name (prop_type), state->prop_spec->name);
 			return;
@@ -580,12 +560,16 @@ gogo_start (GsfXMLIn *xin, xmlChar const **attrs)
 	} else
 		res = NULL;
 
-	if (role != NULL)
-		res = gog_object_add_by_name (state->obj, role, res);
+	if (role != NULL) {
+		if (strcmp (role, GOG_BACKPLANE_OLD_ROLE_NAME) == 0)
+			res = gog_object_add_by_name (state->obj, GOG_BACKPLANE_NEW_ROLE_NAME, res);
+		else
+			res = gog_object_add_by_name (state->obj, role, res);
+	}
 	if (res != NULL) {
 		res->explicitly_typed_role = (type != NULL);
-		if (IS_GOG_PERSIST (res))
-			gog_persist_prep_sax (GOG_PERSIST (res), xin, attrs);
+		if (GO_IS_PERSIST (res))
+			go_persist_prep_sax (GO_PERSIST (res), xin, attrs);
 	}
 
 	state->obj_stack = g_slist_prepend (state->obj_stack, state->obj);
@@ -615,6 +599,7 @@ go_sax_parser_done (GsfXMLIn *xin, GogXMLReadState *state)
 void
 gog_object_sax_push_parser (GsfXMLIn *xin, xmlChar const **attrs,
 			    GogObjectSaxHandler	handler,
+			    gpointer            user_unserialize,
 			    gpointer		user_data)
 {
 	static GsfXMLInNode const dtd[] = {
@@ -633,14 +618,7 @@ gog_object_sax_push_parser (GsfXMLIn *xin, xmlChar const **attrs,
 	state = g_new0 (GogXMLReadState, 1);
 	state->handler = handler;
 	state->user_data = user_data;
+	state->user_unserialize = user_unserialize;
 	gsf_xml_in_push_state (xin, doc, state,
 		(GsfXMLInExtDtor) go_sax_parser_done, attrs);
 }
-
-void
-go_xml_out_add_color (GsfXMLOut *output, char const *id, GOColor c)
-{
-	char *str = go_color_as_str (c);
-	gsf_xml_out_add_cstr_unchecked (output, id, str);
-	g_free (str);
-}
