@@ -34,24 +34,23 @@ typedef struct {
 	double 		 dash[8];
 } GOLineDashDesc;
 
-static const GOLineDashDesc line_short_dot_desc = 		{2, 10,	{ 0, 2 } };
-static const GOLineDashDesc line_dot_desc = 			{2, 12,	{ 3, 3 } };
-static const GOLineDashDesc line_short_dash_desc =		{2, 9,	{ 6, 3 } };
-static const GOLineDashDesc line_short_dash_dot_desc =		{4, 12,	{ 6, 3, 0, 3 } };
-static const GOLineDashDesc line_short_dash_dot_dot_desc =    	{6, 15,	{ 6, 3, 0, 3, 0, 3 } };
-static const GOLineDashDesc line_dash_dot_dot_dot_desc =    	{8, 21,	{ 9, 3, 0, 3, 0, 3, 0, 3 } };
-static const GOLineDashDesc line_dash_dot_desc =		{4, 24,	{ 9, 6, 3, 6 } };
-static const GOLineDashDesc line_dash_dot_dot_desc =    	{6, 24,	{ 9, 3, 3, 3, 3, 3 } };
-static const GOLineDashDesc line_dash_desc =			{2, 16,	{ 12, 4 } };
-static const GOLineDashDesc line_long_dash_desc =		{2, 22,	{ 18, 4 } };
+static GOLineDashDesc const line_short_dot_desc = 		{2, 10,	{ 0, 2 } };
+static GOLineDashDesc const line_dot_desc = 			{2, 12,	{ 3, 3 } };
+static GOLineDashDesc const line_short_dash_desc =		{2, 9,	{ 6, 3 } };
+static GOLineDashDesc const line_short_dash_dot_desc =		{4, 12,	{ 6, 3, 0, 3 } };
+static GOLineDashDesc const line_short_dash_dot_dot_desc =    	{6, 15,	{ 6, 3, 0, 3, 0, 3 } };
+static GOLineDashDesc const line_dash_dot_dot_dot_desc =    	{8, 21,	{ 9, 3, 0, 3, 0, 3, 0, 3 } };
+static GOLineDashDesc const line_dash_dot_desc =		{4, 24,	{ 9, 6, 3, 6 } };
+static GOLineDashDesc const line_dash_dot_dot_desc =    	{6, 24,	{ 9, 3, 3, 3, 3, 3 } };
+static GOLineDashDesc const line_dash_desc =			{2, 16,	{ 12, 4 } };
+static GOLineDashDesc const line_long_dash_desc =		{2, 22,	{ 18, 4 } };
 
 static struct {
 	GOLineDashType type;
 	char const *label;
 	char const *name;
-	const GOLineDashDesc *dash_desc;
-} line_dashes[GO_LINE_MAX] =
-{
+	GOLineDashDesc const *dash_desc;
+} line_dashes[GO_LINE_MAX] = {
 	{ GO_LINE_NONE,			N_("None"),
 		"none",			NULL },
 	{ GO_LINE_SOLID,		N_("Solid"),
@@ -82,24 +81,41 @@ static struct {
 	GOLineInterpolation type;
 	char const *label;
 	char const *name;
+	gboolean supports_radial;
+	gboolean auto_skip;
 } line_interpolations[GO_LINE_INTERPOLATION_MAX] =
 {
-	{ GO_LINE_INTERPOLATION_LINEAR,		N_("Linear"), 		"linear" },
-	{ GO_LINE_INTERPOLATION_SPLINE,		N_("Spline"),		"spline" },
-	{ GO_LINE_INTERPOLATION_STEP_START,	N_("Step at start"), 	"step-start" },
-	{ GO_LINE_INTERPOLATION_STEP_END,	N_("Step at end"),	"step-end" },
-	{ GO_LINE_INTERPOLATION_STEP_CENTER_X,	N_("Step at center"),	"step-center-x" },
-	{ GO_LINE_INTERPOLATION_STEP_CENTER_Y,	N_("Step to mean"),	"step-center-y" }
+	{ GO_LINE_INTERPOLATION_LINEAR,			N_("Linear"),
+		"linear",		TRUE,  FALSE },
+	{ GO_LINE_INTERPOLATION_SPLINE,			N_("Bezier cubic spline"),
+		"spline",		TRUE,  FALSE },
+	{ GO_LINE_INTERPOLATION_CLOSED_SPLINE,		N_("Closed Bezier cubic spline"),
+		"closed-spline",	TRUE,  TRUE },
+	{ GO_LINE_INTERPOLATION_CUBIC_SPLINE,		N_("Natural cubic spline"),
+		"cspline",		FALSE, FALSE },
+	{ GO_LINE_INTERPOLATION_PARABOLIC_CUBIC_SPLINE,	N_("Cubic spline with parabolic extrapolation"),
+		"parabolic-cspline",	FALSE, FALSE },
+	{ GO_LINE_INTERPOLATION_CUBIC_CUBIC_SPLINE,	N_("Cubic spline with cubic extrapolation"),
+		"cubic-cspline",	FALSE, FALSE },
+	{ GO_LINE_INTERPOLATION_CLAMPED_CUBIC_SPLINE,   N_("Clamped cubic spline"),
+		"clamped-cspline",	FALSE, TRUE },
+	{ GO_LINE_INTERPOLATION_STEP_START,		N_("Step at start"),
+		"step-start",		TRUE,  FALSE },
+	{ GO_LINE_INTERPOLATION_STEP_END,		N_("Step at end"),
+		"step-end",		TRUE,  FALSE },
+	{ GO_LINE_INTERPOLATION_STEP_CENTER_X,		N_("Step at center"),
+		"step-center-x",	TRUE,  FALSE },
+	{ GO_LINE_INTERPOLATION_STEP_CENTER_Y,		N_("Step to mean"),
+		"step-center-y",	TRUE,  FALSE }
 };
 
 /**
  * go_line_dash_from_str:
  * @name: Name of the dash type
  *
- * Returns a GOLineDashType corresponding to name, or GO_LINE_NONE
- * if not found.
+ * Returns: a #GOLineDashType corresponding to name, or %GO_LINE_NONE
+ * 	if not found.
  **/
-
 GOLineDashType
 go_line_dash_from_str (char const *name)
 {
@@ -119,10 +135,9 @@ go_line_dash_from_str (char const *name)
  * go_line_dash_as_str:
  * @type: a #GOLineDashType
  *
- * Returns a pointer to the nickname of the dash type, or "none" if 
- * type is invalid. The returning string should not be freed.
+ * Returns: a pointer to the nickname of the dash type, or "none" if 
+ * 	type is invalid. The returning string should not be freed.
  **/
-
 char const *
 go_line_dash_as_str (GOLineDashType type)
 {
@@ -142,11 +157,10 @@ go_line_dash_as_str (GOLineDashType type)
  * go_line_dash_as_label:
  * @type: a #GOLineDashType
  *
- * Returns a pointer to the user readable name of the dash type,
- * or the name of GO_LINE_NONE if type is invalid. The returned
- * string should not be freed.
+ * Returns: a pointer to the user readable name of the dash type,
+ * 	or the name of %GO_LINE_NONE if type is invalid. The returned
+ * 	string should not be freed.
  **/
-
 char const *
 go_line_dash_as_label (GOLineDashType type)
 {
@@ -166,13 +180,12 @@ go_line_dash_as_label (GOLineDashType type)
  * go_line_dash_get_length:
  * @type: #GOLineDashType
  *
- * Returns the unscaled length of the dash sequence.
+ * Returns: the unscaled length of the dash sequence.
  **/
-
 double
 go_line_dash_get_length (GOLineDashType type)
 {
-	const GOLineDashDesc *dash_desc;
+	GOLineDashDesc const *dash_desc;
 
 	if (type < 0 || type >= G_N_ELEMENTS (line_dashes))
 		return 1.0;
@@ -186,17 +199,16 @@ go_line_dash_get_length (GOLineDashType type)
  * @type: a #GOLineDashType
  * @scale: dash scale
  *
- * Returns a struct containing the dash sequence corresponding to @type,
- * or NULL if type is invalid or equal to GO_LINE_NONE.
- * The lengths are scaled according to @scale.
+ * Returns: a struct containing the dash sequence corresponding to @type,
+ * 	or %NULL if type is invalid or equal to %GO_LINE_NONE.
+ * 	The lengths are scaled according to @scale.
  **/
-
 GOLineDashSequence *
 go_line_dash_get_sequence (GOLineDashType type, double scale)
 {
 	unsigned int i;
 	GOLineDashSequence *sequence = NULL;
-	const GOLineDashDesc *dash_desc;
+	GOLineDashDesc const *dash_desc;
 
 	if (type < 0 || type >= G_N_ELEMENTS (line_dashes))
 		return NULL;
@@ -220,7 +232,6 @@ go_line_dash_get_sequence (GOLineDashType type, double scale)
  *
  * Frees the dash sequence struct.
  **/
-
 void
 go_line_dash_sequence_free (GOLineDashSequence *sequence)
 {
@@ -233,10 +244,9 @@ go_line_dash_sequence_free (GOLineDashSequence *sequence)
  * go_line_interpolation_from_str:
  * @name: an interpolation type nickname
  *
- * Returns a #GOLineInterpolation corresponding to @name, or 
- * GO_LINE_INTERPOLATION_LINEAR if not found.
+ * Returns: a #GOLineInterpolation corresponding to @name, or 
+ * 	%GO_LINE_INTERPOLATION_LINEAR if not found.
  **/
-
 GOLineInterpolation
 go_line_interpolation_from_str (char const *name)
 {
@@ -256,10 +266,9 @@ go_line_interpolation_from_str (char const *name)
  * go_line_interpolation_as_str:
  * @type: an interpolation type
  *
- * Returns a pointer to the nickname of @type, or "linear" if type
- * is invalid. The returned string should not be freed.
+ * Returns: a pointer to the nickname of @type, or "linear" if type
+ * 	is invalid. The returned string should not be freed.
  **/
-
 char const *
 go_line_interpolation_as_str (GOLineInterpolation type)
 {
@@ -274,3 +283,66 @@ go_line_interpolation_as_str (GOLineInterpolation type)
 	}
 	return ret;
 }
+
+/**
+ * go_line_interpolation_as_label:
+ * @type: an interpolation type
+ *
+ * Returns: a pointer to the label of @type, or the name of
+ * %GO_LINE_INTERPOLATION_LINEAR if type is invalid.
+ * The returned string should not be freed.
+ **/
+char const *
+go_line_interpolation_as_label (GOLineInterpolation type)
+{
+	unsigned i;
+	char const *ret = _("Linear");
+
+	for (i = 0; i < G_N_ELEMENTS (line_interpolations); i++) {
+		if (line_interpolations[i].type == type) {
+			ret = _(line_interpolations[i].label);
+			break;
+		}
+	}
+	return ret;
+}
+
+/**
+ * go_line_interpolation_as_str:
+ * @type: an interpolation type
+ *
+ * Returns: TRUE if the line interpolation type can be used with radial
+ * axes set, FALSE it it can't.
+ **/
+gboolean
+go_line_interpolation_supports_radial (GOLineInterpolation type)
+{
+	unsigned i;
+
+	for (i = 0; i < G_N_ELEMENTS (line_interpolations); i++) {
+		if (line_interpolations[i].type == type) {
+			return line_interpolations[i].supports_radial;
+		}
+	}
+	return FALSE;
+}
+
+/**
+ * go_line_interpolation_as_str:
+ * @type: an interpolation type
+ *
+ * Returns: TRUE if the line interpolation type forces skipping invalid
+ * data, FALSE if it is only optional.
+ **/
+gboolean
+go_line_interpolation_auto_skip	(GOLineInterpolation type)
+{
+	unsigned i;
+
+	for (i = 0; i < G_N_ELEMENTS (line_interpolations); i++) {
+		if (line_interpolations[i].type == type) {
+			return line_interpolations[i].auto_skip;
+		}
+	}
+	return FALSE;
+}
