@@ -91,7 +91,7 @@ xavg_toggled_cb (GtkToggleButton *button, GObject *ma)
 
 static void
 gog_moving_avg_populate_editor (GogObject *obj, 
-				GogEditor *editor,
+				GOEditor *editor,
 				GogDataAllocator *dalloc,
 				GOCmdContext *cc)
 {
@@ -99,7 +99,7 @@ gog_moving_avg_populate_editor (GogObject *obj,
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_smoothing"));
 	char	 *path = g_build_filename (dir, "gog-moving-avg.glade", NULL);
-	GladeXML *gui = go_libglade_new (path, "mv-avg-prefs", GETTEXT_PACKAGE, cc);
+	GladeXML *gui = go_glade_new (path, "mv-avg-prefs", GETTEXT_PACKAGE, cc);
 	GtkWidget *w = glade_xml_get_widget (gui, "span");
 	go_widget_set_tooltip_text (w, _("Number of values from which to calculate an average"));
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (w), 2, G_MAXINT);
@@ -112,7 +112,7 @@ gog_moving_avg_populate_editor (GogObject *obj,
 	w = glade_xml_get_widget (gui, "mv-avg-prefs");
 	g_object_set_data_full (G_OBJECT (w),
 		"state", gui, (GDestroyNotify) g_object_unref);
-	gog_editor_add_page (editor, w, _("Properties"));
+	go_editor_add_page (editor, w, _("Properties"));
 
 	(GOG_OBJECT_CLASS (moving_avg_parent_klass)->populate_editor) (obj, editor, dalloc, cc);
 }
@@ -215,4 +215,4 @@ gog_moving_avg_init (GogMovingAvg *model)
 
 GSF_DYNAMIC_CLASS (GogMovingAvg, gog_moving_avg,
 	gog_moving_avg_class_init, gog_moving_avg_init,
-	GOG_SMOOTHED_CURVE_TYPE)
+	GOG_TYPE_SMOOTHED_CURVE)
